@@ -3,9 +3,11 @@ import shutil
 
 from pathlib import Path
 
-from steinbock._env import cellprofiler_binary, cellprofiler_plugin_dir
 from steinbock.measurement import cellprofiler
 
+cellprofiler_binary = "cellprofiler"
+cellprofiler_plugin_dir = "/opt/cellprofiler_plugins"
+
 
 class TestCellprofilerMeasurement:
     def test_create_and_save_measurement_pipeline(self, tmp_path: Path):
